@@ -4,7 +4,7 @@ Main interface for mturk service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_mturk import (
         Client,
         ListAssignmentsForHITPaginator,
@@ -19,10 +19,8 @@ Usage::
         MTurkClient,
     )
 
-    session = boto3.Session()
-
-    client: MTurkClient = boto3.client("mturk")
-    session_client: MTurkClient = session.client("mturk")
+    session = Session()
+    client: MTurkClient = session.client("mturk")
 
     list_assignments_for_hit_paginator: ListAssignmentsForHITPaginator = client.get_paginator("list_assignments_for_hit")
     list_bonus_payments_paginator: ListBonusPaymentsPaginator = client.get_paginator("list_bonus_payments")
