@@ -6,10 +6,11 @@ Type annotations for mturk service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_mturk import MTurkClient
+    from boto3.session import Session
+    from mypy_boto3_mturk.client import MTurkClient
 
-    client: MTurkClient = boto3.client("mturk")
+    session = Session()
+    client: MTurkClient = session.client("mturk")
     ```
 """
 import sys
@@ -91,7 +92,7 @@ class Exceptions:
 
 class MTurkClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html)
     """
 
@@ -101,6 +102,9 @@ class MTurkClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         MTurkClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#exceptions)
         """
 
     def accept_qualification_request(
@@ -110,7 +114,7 @@ class MTurkClient(BaseClient):
         The `AcceptQualificationRequest` operation approves a Worker's request for a
         Qualification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.accept_qualification_request)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.accept_qualification_request)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#accept_qualification_request)
         """
 
@@ -121,7 +125,7 @@ class MTurkClient(BaseClient):
         The `ApproveAssignment` operation approves the results of a completed
         assignment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.approve_assignment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.approve_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#approve_assignment)
         """
 
@@ -136,7 +140,7 @@ class MTurkClient(BaseClient):
         """
         The `AssociateQualificationWithWorker` operation gives a Worker a Qualification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.associate_qualification_with_worker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.associate_qualification_with_worker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#associate_qualification_with_worker)
         """
 
@@ -144,7 +148,7 @@ class MTurkClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#can_paginate)
         """
 
@@ -155,7 +159,7 @@ class MTurkClient(BaseClient):
         The `CreateAdditionalAssignmentsForHIT` operation increases the maximum number
         of assignments of an existing HIT.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.create_additional_assignments_for_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.create_additional_assignments_for_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#create_additional_assignments_for_hit)
         """
 
@@ -182,7 +186,7 @@ class MTurkClient(BaseClient):
         """
         The `CreateHIT` operation creates a new Human Intelligence Task (HIT).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.create_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.create_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#create_hit)
         """
 
@@ -200,7 +204,7 @@ class MTurkClient(BaseClient):
         """
         The `CreateHITType` operation creates a new HIT type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.create_hit_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.create_hit_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#create_hit_type)
         """
 
@@ -222,7 +226,7 @@ class MTurkClient(BaseClient):
         The `CreateHITWithHITType` operation creates a new Human Intelligence Task (HIT)
         using an existing HITTypeID generated by the `CreateHITType` operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.create_hit_with_hit_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.create_hit_with_hit_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#create_hit_with_hit_type)
         """
 
@@ -244,7 +248,7 @@ class MTurkClient(BaseClient):
         The `CreateQualificationType` operation creates a new Qualification type, which
         is represented by a `QualificationType` data structure.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.create_qualification_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.create_qualification_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#create_qualification_type)
         """
 
@@ -253,7 +257,7 @@ class MTurkClient(BaseClient):
         The `CreateWorkerBlock` operation allows you to prevent a Worker from working on
         your HITs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.create_worker_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.create_worker_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#create_worker_block)
         """
 
@@ -261,7 +265,7 @@ class MTurkClient(BaseClient):
         """
         The `DeleteHIT` operation is used to delete HIT that is no longer needed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.delete_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.delete_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#delete_hit)
         """
 
@@ -270,7 +274,7 @@ class MTurkClient(BaseClient):
         The `DeleteQualificationType` deletes a Qualification type and deletes any HIT
         types that are associated with the Qualification type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.delete_qualification_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.delete_qualification_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#delete_qualification_type)
         """
 
@@ -279,7 +283,7 @@ class MTurkClient(BaseClient):
         The `DeleteWorkerBlock` operation allows you to reinstate a blocked Worker to
         work on your HITs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.delete_worker_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.delete_worker_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#delete_worker_block)
         """
 
@@ -290,7 +294,7 @@ class MTurkClient(BaseClient):
         The `DisassociateQualificationFromWorker` revokes a previously granted
         Qualification from a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.disassociate_qualification_from_worker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.disassociate_qualification_from_worker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#disassociate_qualification_from_worker)
         """
 
@@ -304,7 +308,7 @@ class MTurkClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#generate_presigned_url)
         """
 
@@ -313,7 +317,7 @@ class MTurkClient(BaseClient):
         The `GetAccountBalance` operation retrieves the Prepaid HITs balance in your
         Amazon Mechanical Turk account if you are a Prepaid Requester.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.get_account_balance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_account_balance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_account_balance)
         """
 
@@ -321,7 +325,7 @@ class MTurkClient(BaseClient):
         """
         The `GetAssignment` operation retrieves the details of the specified Assignment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.get_assignment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_assignment)
         """
 
@@ -331,7 +335,7 @@ class MTurkClient(BaseClient):
         """
         The `GetFileUploadURL` operation generates and returns a temporary URL.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.get_file_upload_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_file_upload_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_file_upload_url)
         """
 
@@ -339,7 +343,7 @@ class MTurkClient(BaseClient):
         """
         The `GetHIT` operation retrieves the details of the specified HIT.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.get_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_hit)
         """
 
@@ -350,7 +354,7 @@ class MTurkClient(BaseClient):
         The `GetQualificationScore` operation returns the value of a Worker's
         Qualification for a given Qualification type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.get_qualification_score)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_qualification_score)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_qualification_score)
         """
 
@@ -361,7 +365,7 @@ class MTurkClient(BaseClient):
         The `GetQualificationType` operation retrieves information about a Qualification
         type using its ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.get_qualification_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_qualification_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_qualification_type)
         """
 
@@ -376,7 +380,7 @@ class MTurkClient(BaseClient):
         """
         The `ListAssignmentsForHIT` operation retrieves completed assignments for a HIT.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_assignments_for_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_assignments_for_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_assignments_for_hit)
         """
 
@@ -392,7 +396,7 @@ class MTurkClient(BaseClient):
         The `ListBonusPayments` operation retrieves the amounts of bonuses you have paid
         to Workers for a given HIT or assignment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_bonus_payments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_bonus_payments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_bonus_payments)
         """
 
@@ -400,7 +404,7 @@ class MTurkClient(BaseClient):
         """
         The `ListHITs` operation returns all of a Requester's HITs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_hits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_hits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_hits)
         """
 
@@ -411,7 +415,7 @@ class MTurkClient(BaseClient):
         The `ListHITsForQualificationType` operation returns the HITs that use the given
         Qualification type for a Qualification requirement.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_hits_for_qualification_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_hits_for_qualification_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_hits_for_qualification_type)
         """
 
@@ -422,7 +426,7 @@ class MTurkClient(BaseClient):
         The `ListQualificationRequests` operation retrieves requests for Qualifications
         of a particular Qualification type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_qualification_requests)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_qualification_requests)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_qualification_requests)
         """
 
@@ -439,7 +443,7 @@ class MTurkClient(BaseClient):
         The `ListQualificationTypes` operation returns a list of Qualification types,
         filtered by an optional search term.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_qualification_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_qualification_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_qualification_types)
         """
 
@@ -458,7 +462,7 @@ class MTurkClient(BaseClient):
         the actions taken in the course of executing your Review Policies for a given
         HIT.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_review_policy_results_for_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_review_policy_results_for_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_review_policy_results_for_hit)
         """
 
@@ -475,7 +479,7 @@ class MTurkClient(BaseClient):
         Reviewable or Status equal to Reviewing that belong to the Requester calling the
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_reviewable_hits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_reviewable_hits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_reviewable_hits)
         """
 
@@ -486,7 +490,7 @@ class MTurkClient(BaseClient):
         The `ListWorkersBlocks` operation retrieves a list of Workers who are blocked
         from working on your HITs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_worker_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_worker_blocks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_worker_blocks)
         """
 
@@ -502,7 +506,7 @@ class MTurkClient(BaseClient):
         The `ListWorkersWithQualificationType` operation returns all of the Workers that
         have been associated with a given Qualification type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.list_workers_with_qualification_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.list_workers_with_qualification_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#list_workers_with_qualification_type)
         """
 
@@ -513,7 +517,7 @@ class MTurkClient(BaseClient):
         The `NotifyWorkers` operation sends an email to one or more Workers that you
         specify with the Worker ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.notify_workers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.notify_workers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#notify_workers)
         """
 
@@ -521,7 +525,7 @@ class MTurkClient(BaseClient):
         """
         The `RejectAssignment` operation rejects the results of a completed assignment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.reject_assignment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.reject_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#reject_assignment)
         """
 
@@ -532,7 +536,7 @@ class MTurkClient(BaseClient):
         The `RejectQualificationRequest` operation rejects a user's request for a
         Qualification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.reject_qualification_request)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.reject_qualification_request)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#reject_qualification_request)
         """
 
@@ -549,7 +553,7 @@ class MTurkClient(BaseClient):
         The `SendBonus` operation issues a payment of money from your account to a
         Worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.send_bonus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.send_bonus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#send_bonus)
         """
 
@@ -561,7 +565,7 @@ class MTurkClient(BaseClient):
         a notification message as if a HIT event occurred, according to the provided
         notification specification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.send_test_event_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.send_test_event_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#send_test_event_notification)
         """
 
@@ -572,7 +576,7 @@ class MTurkClient(BaseClient):
         The `UpdateExpirationForHIT` operation allows you update the expiration time of
         a HIT.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.update_expiration_for_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.update_expiration_for_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#update_expiration_for_hit)
         """
 
@@ -580,7 +584,7 @@ class MTurkClient(BaseClient):
         """
         The `UpdateHITReviewStatus` operation updates the status of a HIT.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.update_hit_review_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.update_hit_review_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#update_hit_review_status)
         """
 
@@ -589,7 +593,7 @@ class MTurkClient(BaseClient):
         The `UpdateHITTypeOfHIT` operation allows you to change the HITType properties
         of a HIT.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.update_hit_type_of_hit)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.update_hit_type_of_hit)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#update_hit_type_of_hit)
         """
 
@@ -604,7 +608,7 @@ class MTurkClient(BaseClient):
         The `UpdateNotificationSettings` operation creates, updates, disables or re-
         enables notifications for a HIT type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.update_notification_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.update_notification_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#update_notification_settings)
         """
 
@@ -625,7 +629,7 @@ class MTurkClient(BaseClient):
         The `UpdateQualificationType` operation modifies the attributes of an existing
         Qualification type, which is represented by a QualificationType data structure.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Client.update_qualification_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.update_qualification_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#update_qualification_type)
         """
 
@@ -634,8 +638,8 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_assignments_for_hit"]
     ) -> ListAssignmentsForHITPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListAssignmentsForHIT)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listassignmentsforhitpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
@@ -643,15 +647,15 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_bonus_payments"]
     ) -> ListBonusPaymentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListBonusPayments)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listbonuspaymentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hits"]) -> ListHITsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListHITs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listhitspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
@@ -659,8 +663,8 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_hits_for_qualification_type"]
     ) -> ListHITsForQualificationTypePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListHITsForQualificationType)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listhitsforqualificationtypepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
@@ -668,8 +672,8 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_qualification_requests"]
     ) -> ListQualificationRequestsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListQualificationRequests)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listqualificationrequestspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
@@ -677,8 +681,8 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_qualification_types"]
     ) -> ListQualificationTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListQualificationTypes)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listqualificationtypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
@@ -686,8 +690,8 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_reviewable_hits"]
     ) -> ListReviewableHITsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListReviewableHITs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listreviewablehitspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
@@ -695,8 +699,8 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_worker_blocks"]
     ) -> ListWorkerBlocksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListWorkerBlocks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listworkerblockspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
 
     @overload
@@ -704,6 +708,6 @@ class MTurkClient(BaseClient):
         self, operation_name: Literal["list_workers_with_qualification_type"]
     ) -> ListWorkersWithQualificationTypePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/mturk.html#MTurk.Paginator.ListWorkersWithQualificationType)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/paginators.html#listworkerswithqualificationtypepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#MTurk.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mturk/client.html#get_paginator)
         """
