@@ -13,7 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence, Union
+from typing import Dict, List, Sequence, Union
+
+from typing_extensions import NotRequired
 
 from .literals import (
     AssignmentStatusType,
@@ -120,162 +122,92 @@ __all__ = (
     "WorkerBlockTypeDef",
 )
 
-_RequiredAcceptQualificationRequestRequestRequestTypeDef = TypedDict(
-    "_RequiredAcceptQualificationRequestRequestRequestTypeDef",
+AcceptQualificationRequestRequestRequestTypeDef = TypedDict(
+    "AcceptQualificationRequestRequestRequestTypeDef",
     {
         "QualificationRequestId": str,
+        "IntegerValue": NotRequired[int],
     },
 )
-_OptionalAcceptQualificationRequestRequestRequestTypeDef = TypedDict(
-    "_OptionalAcceptQualificationRequestRequestRequestTypeDef",
-    {
-        "IntegerValue": int,
-    },
-    total=False,
-)
 
-
-class AcceptQualificationRequestRequestRequestTypeDef(
-    _RequiredAcceptQualificationRequestRequestRequestTypeDef,
-    _OptionalAcceptQualificationRequestRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredApproveAssignmentRequestRequestTypeDef = TypedDict(
-    "_RequiredApproveAssignmentRequestRequestTypeDef",
+ApproveAssignmentRequestRequestTypeDef = TypedDict(
+    "ApproveAssignmentRequestRequestTypeDef",
     {
         "AssignmentId": str,
+        "RequesterFeedback": NotRequired[str],
+        "OverrideRejection": NotRequired[bool],
     },
 )
-_OptionalApproveAssignmentRequestRequestTypeDef = TypedDict(
-    "_OptionalApproveAssignmentRequestRequestTypeDef",
-    {
-        "RequesterFeedback": str,
-        "OverrideRejection": bool,
-    },
-    total=False,
-)
-
-
-class ApproveAssignmentRequestRequestTypeDef(
-    _RequiredApproveAssignmentRequestRequestTypeDef, _OptionalApproveAssignmentRequestRequestTypeDef
-):
-    pass
-
 
 AssignmentTypeDef = TypedDict(
     "AssignmentTypeDef",
     {
-        "AssignmentId": str,
-        "WorkerId": str,
-        "HITId": str,
-        "AssignmentStatus": AssignmentStatusType,
-        "AutoApprovalTime": datetime,
-        "AcceptTime": datetime,
-        "SubmitTime": datetime,
-        "ApprovalTime": datetime,
-        "RejectionTime": datetime,
-        "Deadline": datetime,
-        "Answer": str,
-        "RequesterFeedback": str,
+        "AssignmentId": NotRequired[str],
+        "WorkerId": NotRequired[str],
+        "HITId": NotRequired[str],
+        "AssignmentStatus": NotRequired[AssignmentStatusType],
+        "AutoApprovalTime": NotRequired[datetime],
+        "AcceptTime": NotRequired[datetime],
+        "SubmitTime": NotRequired[datetime],
+        "ApprovalTime": NotRequired[datetime],
+        "RejectionTime": NotRequired[datetime],
+        "Deadline": NotRequired[datetime],
+        "Answer": NotRequired[str],
+        "RequesterFeedback": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredAssociateQualificationWithWorkerRequestRequestTypeDef = TypedDict(
-    "_RequiredAssociateQualificationWithWorkerRequestRequestTypeDef",
+AssociateQualificationWithWorkerRequestRequestTypeDef = TypedDict(
+    "AssociateQualificationWithWorkerRequestRequestTypeDef",
     {
         "QualificationTypeId": str,
         "WorkerId": str,
+        "IntegerValue": NotRequired[int],
+        "SendNotification": NotRequired[bool],
     },
 )
-_OptionalAssociateQualificationWithWorkerRequestRequestTypeDef = TypedDict(
-    "_OptionalAssociateQualificationWithWorkerRequestRequestTypeDef",
-    {
-        "IntegerValue": int,
-        "SendNotification": bool,
-    },
-    total=False,
-)
-
-
-class AssociateQualificationWithWorkerRequestRequestTypeDef(
-    _RequiredAssociateQualificationWithWorkerRequestRequestTypeDef,
-    _OptionalAssociateQualificationWithWorkerRequestRequestTypeDef,
-):
-    pass
-
 
 BonusPaymentTypeDef = TypedDict(
     "BonusPaymentTypeDef",
     {
-        "WorkerId": str,
-        "BonusAmount": str,
-        "AssignmentId": str,
-        "Reason": str,
-        "GrantTime": datetime,
+        "WorkerId": NotRequired[str],
+        "BonusAmount": NotRequired[str],
+        "AssignmentId": NotRequired[str],
+        "Reason": NotRequired[str],
+        "GrantTime": NotRequired[datetime],
     },
-    total=False,
 )
 
-_RequiredCreateAdditionalAssignmentsForHITRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAdditionalAssignmentsForHITRequestRequestTypeDef",
+CreateAdditionalAssignmentsForHITRequestRequestTypeDef = TypedDict(
+    "CreateAdditionalAssignmentsForHITRequestRequestTypeDef",
     {
         "HITId": str,
         "NumberOfAdditionalAssignments": int,
+        "UniqueRequestToken": NotRequired[str],
     },
 )
-_OptionalCreateAdditionalAssignmentsForHITRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAdditionalAssignmentsForHITRequestRequestTypeDef",
-    {
-        "UniqueRequestToken": str,
-    },
-    total=False,
-)
 
-
-class CreateAdditionalAssignmentsForHITRequestRequestTypeDef(
-    _RequiredCreateAdditionalAssignmentsForHITRequestRequestTypeDef,
-    _OptionalCreateAdditionalAssignmentsForHITRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredCreateHITRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateHITRequestRequestTypeDef",
+CreateHITRequestRequestTypeDef = TypedDict(
+    "CreateHITRequestRequestTypeDef",
     {
         "LifetimeInSeconds": int,
         "AssignmentDurationInSeconds": int,
         "Reward": str,
         "Title": str,
         "Description": str,
+        "MaxAssignments": NotRequired[int],
+        "AutoApprovalDelayInSeconds": NotRequired[int],
+        "Keywords": NotRequired[str],
+        "Question": NotRequired[str],
+        "RequesterAnnotation": NotRequired[str],
+        "QualificationRequirements": NotRequired[Sequence["QualificationRequirementTypeDef"]],
+        "UniqueRequestToken": NotRequired[str],
+        "AssignmentReviewPolicy": NotRequired["ReviewPolicyTypeDef"],
+        "HITReviewPolicy": NotRequired["ReviewPolicyTypeDef"],
+        "HITLayoutId": NotRequired[str],
+        "HITLayoutParameters": NotRequired[Sequence["HITLayoutParameterTypeDef"]],
     },
 )
-_OptionalCreateHITRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateHITRequestRequestTypeDef",
-    {
-        "MaxAssignments": int,
-        "AutoApprovalDelayInSeconds": int,
-        "Keywords": str,
-        "Question": str,
-        "RequesterAnnotation": str,
-        "QualificationRequirements": Sequence["QualificationRequirementTypeDef"],
-        "UniqueRequestToken": str,
-        "AssignmentReviewPolicy": "ReviewPolicyTypeDef",
-        "HITReviewPolicy": "ReviewPolicyTypeDef",
-        "HITLayoutId": str,
-        "HITLayoutParameters": Sequence["HITLayoutParameterTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateHITRequestRequestTypeDef(
-    _RequiredCreateHITRequestRequestTypeDef, _OptionalCreateHITRequestRequestTypeDef
-):
-    pass
-
 
 CreateHITResponseTypeDef = TypedDict(
     "CreateHITResponseTypeDef",
@@ -285,31 +217,18 @@ CreateHITResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateHITTypeRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateHITTypeRequestRequestTypeDef",
+CreateHITTypeRequestRequestTypeDef = TypedDict(
+    "CreateHITTypeRequestRequestTypeDef",
     {
         "AssignmentDurationInSeconds": int,
         "Reward": str,
         "Title": str,
         "Description": str,
+        "AutoApprovalDelayInSeconds": NotRequired[int],
+        "Keywords": NotRequired[str],
+        "QualificationRequirements": NotRequired[Sequence["QualificationRequirementTypeDef"]],
     },
 )
-_OptionalCreateHITTypeRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateHITTypeRequestRequestTypeDef",
-    {
-        "AutoApprovalDelayInSeconds": int,
-        "Keywords": str,
-        "QualificationRequirements": Sequence["QualificationRequirementTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateHITTypeRequestRequestTypeDef(
-    _RequiredCreateHITTypeRequestRequestTypeDef, _OptionalCreateHITTypeRequestRequestTypeDef
-):
-    pass
-
 
 CreateHITTypeResponseTypeDef = TypedDict(
     "CreateHITTypeResponseTypeDef",
@@ -319,35 +238,21 @@ CreateHITTypeResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateHITWithHITTypeRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateHITWithHITTypeRequestRequestTypeDef",
+CreateHITWithHITTypeRequestRequestTypeDef = TypedDict(
+    "CreateHITWithHITTypeRequestRequestTypeDef",
     {
         "HITTypeId": str,
         "LifetimeInSeconds": int,
+        "MaxAssignments": NotRequired[int],
+        "Question": NotRequired[str],
+        "RequesterAnnotation": NotRequired[str],
+        "UniqueRequestToken": NotRequired[str],
+        "AssignmentReviewPolicy": NotRequired["ReviewPolicyTypeDef"],
+        "HITReviewPolicy": NotRequired["ReviewPolicyTypeDef"],
+        "HITLayoutId": NotRequired[str],
+        "HITLayoutParameters": NotRequired[Sequence["HITLayoutParameterTypeDef"]],
     },
 )
-_OptionalCreateHITWithHITTypeRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateHITWithHITTypeRequestRequestTypeDef",
-    {
-        "MaxAssignments": int,
-        "Question": str,
-        "RequesterAnnotation": str,
-        "UniqueRequestToken": str,
-        "AssignmentReviewPolicy": "ReviewPolicyTypeDef",
-        "HITReviewPolicy": "ReviewPolicyTypeDef",
-        "HITLayoutId": str,
-        "HITLayoutParameters": Sequence["HITLayoutParameterTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateHITWithHITTypeRequestRequestTypeDef(
-    _RequiredCreateHITWithHITTypeRequestRequestTypeDef,
-    _OptionalCreateHITWithHITTypeRequestRequestTypeDef,
-):
-    pass
-
 
 CreateHITWithHITTypeResponseTypeDef = TypedDict(
     "CreateHITWithHITTypeResponseTypeDef",
@@ -357,35 +262,21 @@ CreateHITWithHITTypeResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateQualificationTypeRequestRequestTypeDef",
+CreateQualificationTypeRequestRequestTypeDef = TypedDict(
+    "CreateQualificationTypeRequestRequestTypeDef",
     {
         "Name": str,
         "Description": str,
         "QualificationTypeStatus": QualificationTypeStatusType,
+        "Keywords": NotRequired[str],
+        "RetryDelayInSeconds": NotRequired[int],
+        "Test": NotRequired[str],
+        "AnswerKey": NotRequired[str],
+        "TestDurationInSeconds": NotRequired[int],
+        "AutoGranted": NotRequired[bool],
+        "AutoGrantedValue": NotRequired[int],
     },
 )
-_OptionalCreateQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateQualificationTypeRequestRequestTypeDef",
-    {
-        "Keywords": str,
-        "RetryDelayInSeconds": int,
-        "Test": str,
-        "AnswerKey": str,
-        "TestDurationInSeconds": int,
-        "AutoGranted": bool,
-        "AutoGrantedValue": int,
-    },
-    total=False,
-)
-
-
-class CreateQualificationTypeRequestRequestTypeDef(
-    _RequiredCreateQualificationTypeRequestRequestTypeDef,
-    _OptionalCreateQualificationTypeRequestRequestTypeDef,
-):
-    pass
-
 
 CreateQualificationTypeResponseTypeDef = TypedDict(
     "CreateQualificationTypeResponseTypeDef",
@@ -417,49 +308,22 @@ DeleteQualificationTypeRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteWorkerBlockRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteWorkerBlockRequestRequestTypeDef",
+DeleteWorkerBlockRequestRequestTypeDef = TypedDict(
+    "DeleteWorkerBlockRequestRequestTypeDef",
     {
         "WorkerId": str,
+        "Reason": NotRequired[str],
     },
 )
-_OptionalDeleteWorkerBlockRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteWorkerBlockRequestRequestTypeDef",
-    {
-        "Reason": str,
-    },
-    total=False,
-)
 
-
-class DeleteWorkerBlockRequestRequestTypeDef(
-    _RequiredDeleteWorkerBlockRequestRequestTypeDef, _OptionalDeleteWorkerBlockRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredDisassociateQualificationFromWorkerRequestRequestTypeDef = TypedDict(
-    "_RequiredDisassociateQualificationFromWorkerRequestRequestTypeDef",
+DisassociateQualificationFromWorkerRequestRequestTypeDef = TypedDict(
+    "DisassociateQualificationFromWorkerRequestRequestTypeDef",
     {
         "WorkerId": str,
         "QualificationTypeId": str,
+        "Reason": NotRequired[str],
     },
 )
-_OptionalDisassociateQualificationFromWorkerRequestRequestTypeDef = TypedDict(
-    "_OptionalDisassociateQualificationFromWorkerRequestRequestTypeDef",
-    {
-        "Reason": str,
-    },
-    total=False,
-)
-
-
-class DisassociateQualificationFromWorkerRequestRequestTypeDef(
-    _RequiredDisassociateQualificationFromWorkerRequestRequestTypeDef,
-    _OptionalDisassociateQualificationFromWorkerRequestRequestTypeDef,
-):
-    pass
-
 
 GetAccountBalanceResponseTypeDef = TypedDict(
     "GetAccountBalanceResponseTypeDef",
@@ -559,54 +423,39 @@ HITLayoutParameterTypeDef = TypedDict(
 HITTypeDef = TypedDict(
     "HITTypeDef",
     {
-        "HITId": str,
-        "HITTypeId": str,
-        "HITGroupId": str,
-        "HITLayoutId": str,
-        "CreationTime": datetime,
-        "Title": str,
-        "Description": str,
-        "Question": str,
-        "Keywords": str,
-        "HITStatus": HITStatusType,
-        "MaxAssignments": int,
-        "Reward": str,
-        "AutoApprovalDelayInSeconds": int,
-        "Expiration": datetime,
-        "AssignmentDurationInSeconds": int,
-        "RequesterAnnotation": str,
-        "QualificationRequirements": List["QualificationRequirementTypeDef"],
-        "HITReviewStatus": HITReviewStatusType,
-        "NumberOfAssignmentsPending": int,
-        "NumberOfAssignmentsAvailable": int,
-        "NumberOfAssignmentsCompleted": int,
+        "HITId": NotRequired[str],
+        "HITTypeId": NotRequired[str],
+        "HITGroupId": NotRequired[str],
+        "HITLayoutId": NotRequired[str],
+        "CreationTime": NotRequired[datetime],
+        "Title": NotRequired[str],
+        "Description": NotRequired[str],
+        "Question": NotRequired[str],
+        "Keywords": NotRequired[str],
+        "HITStatus": NotRequired[HITStatusType],
+        "MaxAssignments": NotRequired[int],
+        "Reward": NotRequired[str],
+        "AutoApprovalDelayInSeconds": NotRequired[int],
+        "Expiration": NotRequired[datetime],
+        "AssignmentDurationInSeconds": NotRequired[int],
+        "RequesterAnnotation": NotRequired[str],
+        "QualificationRequirements": NotRequired[List["QualificationRequirementTypeDef"]],
+        "HITReviewStatus": NotRequired[HITReviewStatusType],
+        "NumberOfAssignmentsPending": NotRequired[int],
+        "NumberOfAssignmentsAvailable": NotRequired[int],
+        "NumberOfAssignmentsCompleted": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredListAssignmentsForHITRequestRequestTypeDef = TypedDict(
-    "_RequiredListAssignmentsForHITRequestRequestTypeDef",
+ListAssignmentsForHITRequestRequestTypeDef = TypedDict(
+    "ListAssignmentsForHITRequestRequestTypeDef",
     {
         "HITId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "AssignmentStatuses": NotRequired[Sequence[AssignmentStatusType]],
     },
 )
-_OptionalListAssignmentsForHITRequestRequestTypeDef = TypedDict(
-    "_OptionalListAssignmentsForHITRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-        "AssignmentStatuses": Sequence[AssignmentStatusType],
-    },
-    total=False,
-)
-
-
-class ListAssignmentsForHITRequestRequestTypeDef(
-    _RequiredListAssignmentsForHITRequestRequestTypeDef,
-    _OptionalListAssignmentsForHITRequestRequestTypeDef,
-):
-    pass
-
 
 ListAssignmentsForHITResponseTypeDef = TypedDict(
     "ListAssignmentsForHITResponseTypeDef",
@@ -621,12 +470,11 @@ ListAssignmentsForHITResponseTypeDef = TypedDict(
 ListBonusPaymentsRequestRequestTypeDef = TypedDict(
     "ListBonusPaymentsRequestRequestTypeDef",
     {
-        "HITId": str,
-        "AssignmentId": str,
-        "NextToken": str,
-        "MaxResults": int,
+        "HITId": NotRequired[str],
+        "AssignmentId": NotRequired[str],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListBonusPaymentsResponseTypeDef = TypedDict(
@@ -639,28 +487,14 @@ ListBonusPaymentsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListHITsForQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_RequiredListHITsForQualificationTypeRequestRequestTypeDef",
+ListHITsForQualificationTypeRequestRequestTypeDef = TypedDict(
+    "ListHITsForQualificationTypeRequestRequestTypeDef",
     {
         "QualificationTypeId": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListHITsForQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_OptionalListHITsForQualificationTypeRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListHITsForQualificationTypeRequestRequestTypeDef(
-    _RequiredListHITsForQualificationTypeRequestRequestTypeDef,
-    _OptionalListHITsForQualificationTypeRequestRequestTypeDef,
-):
-    pass
-
 
 ListHITsForQualificationTypeResponseTypeDef = TypedDict(
     "ListHITsForQualificationTypeResponseTypeDef",
@@ -675,10 +509,9 @@ ListHITsForQualificationTypeResponseTypeDef = TypedDict(
 ListHITsRequestRequestTypeDef = TypedDict(
     "ListHITsRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListHITsResponseTypeDef = TypedDict(
@@ -694,11 +527,10 @@ ListHITsResponseTypeDef = TypedDict(
 ListQualificationRequestsRequestRequestTypeDef = TypedDict(
     "ListQualificationRequestsRequestRequestTypeDef",
     {
-        "QualificationTypeId": str,
-        "NextToken": str,
-        "MaxResults": int,
+        "QualificationTypeId": NotRequired[str],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListQualificationRequestsResponseTypeDef = TypedDict(
@@ -711,30 +543,16 @@ ListQualificationRequestsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListQualificationTypesRequestRequestTypeDef = TypedDict(
-    "_RequiredListQualificationTypesRequestRequestTypeDef",
+ListQualificationTypesRequestRequestTypeDef = TypedDict(
+    "ListQualificationTypesRequestRequestTypeDef",
     {
         "MustBeRequestable": bool,
+        "Query": NotRequired[str],
+        "MustBeOwnedByCaller": NotRequired[bool],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListQualificationTypesRequestRequestTypeDef = TypedDict(
-    "_OptionalListQualificationTypesRequestRequestTypeDef",
-    {
-        "Query": str,
-        "MustBeOwnedByCaller": bool,
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListQualificationTypesRequestRequestTypeDef(
-    _RequiredListQualificationTypesRequestRequestTypeDef,
-    _OptionalListQualificationTypesRequestRequestTypeDef,
-):
-    pass
-
 
 ListQualificationTypesResponseTypeDef = TypedDict(
     "ListQualificationTypesResponseTypeDef",
@@ -746,31 +564,17 @@ ListQualificationTypesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListReviewPolicyResultsForHITRequestRequestTypeDef = TypedDict(
-    "_RequiredListReviewPolicyResultsForHITRequestRequestTypeDef",
+ListReviewPolicyResultsForHITRequestRequestTypeDef = TypedDict(
+    "ListReviewPolicyResultsForHITRequestRequestTypeDef",
     {
         "HITId": str,
+        "PolicyLevels": NotRequired[Sequence[ReviewPolicyLevelType]],
+        "RetrieveActions": NotRequired[bool],
+        "RetrieveResults": NotRequired[bool],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListReviewPolicyResultsForHITRequestRequestTypeDef = TypedDict(
-    "_OptionalListReviewPolicyResultsForHITRequestRequestTypeDef",
-    {
-        "PolicyLevels": Sequence[ReviewPolicyLevelType],
-        "RetrieveActions": bool,
-        "RetrieveResults": bool,
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListReviewPolicyResultsForHITRequestRequestTypeDef(
-    _RequiredListReviewPolicyResultsForHITRequestRequestTypeDef,
-    _OptionalListReviewPolicyResultsForHITRequestRequestTypeDef,
-):
-    pass
-
 
 ListReviewPolicyResultsForHITResponseTypeDef = TypedDict(
     "ListReviewPolicyResultsForHITResponseTypeDef",
@@ -788,12 +592,11 @@ ListReviewPolicyResultsForHITResponseTypeDef = TypedDict(
 ListReviewableHITsRequestRequestTypeDef = TypedDict(
     "ListReviewableHITsRequestRequestTypeDef",
     {
-        "HITTypeId": str,
-        "Status": ReviewableHITStatusType,
-        "NextToken": str,
-        "MaxResults": int,
+        "HITTypeId": NotRequired[str],
+        "Status": NotRequired[ReviewableHITStatusType],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListReviewableHITsResponseTypeDef = TypedDict(
@@ -809,10 +612,9 @@ ListReviewableHITsResponseTypeDef = TypedDict(
 ListWorkerBlocksRequestRequestTypeDef = TypedDict(
     "ListWorkerBlocksRequestRequestTypeDef",
     {
-        "NextToken": str,
-        "MaxResults": int,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListWorkerBlocksResponseTypeDef = TypedDict(
@@ -825,29 +627,15 @@ ListWorkerBlocksResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListWorkersWithQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_RequiredListWorkersWithQualificationTypeRequestRequestTypeDef",
+ListWorkersWithQualificationTypeRequestRequestTypeDef = TypedDict(
+    "ListWorkersWithQualificationTypeRequestRequestTypeDef",
     {
         "QualificationTypeId": str,
+        "Status": NotRequired[QualificationStatusType],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListWorkersWithQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_OptionalListWorkersWithQualificationTypeRequestRequestTypeDef",
-    {
-        "Status": QualificationStatusType,
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListWorkersWithQualificationTypeRequestRequestTypeDef(
-    _RequiredListWorkersWithQualificationTypeRequestRequestTypeDef,
-    _OptionalListWorkersWithQualificationTypeRequestRequestTypeDef,
-):
-    pass
-
 
 ListWorkersWithQualificationTypeResponseTypeDef = TypedDict(
     "ListWorkersWithQualificationTypeResponseTypeDef",
@@ -859,24 +647,13 @@ ListWorkersWithQualificationTypeResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredLocaleTypeDef = TypedDict(
-    "_RequiredLocaleTypeDef",
+LocaleTypeDef = TypedDict(
+    "LocaleTypeDef",
     {
         "Country": str,
+        "Subdivision": NotRequired[str],
     },
 )
-_OptionalLocaleTypeDef = TypedDict(
-    "_OptionalLocaleTypeDef",
-    {
-        "Subdivision": str,
-    },
-    total=False,
-)
-
-
-class LocaleTypeDef(_RequiredLocaleTypeDef, _OptionalLocaleTypeDef):
-    pass
-
 
 NotificationSpecificationTypeDef = TypedDict(
     "NotificationSpecificationTypeDef",
@@ -891,11 +668,10 @@ NotificationSpecificationTypeDef = TypedDict(
 NotifyWorkersFailureStatusTypeDef = TypedDict(
     "NotifyWorkersFailureStatusTypeDef",
     {
-        "NotifyWorkersFailureCode": NotifyWorkersFailureCodeType,
-        "NotifyWorkersFailureMessage": str,
-        "WorkerId": str,
+        "NotifyWorkersFailureCode": NotRequired[NotifyWorkersFailureCodeType],
+        "NotifyWorkersFailureMessage": NotRequired[str],
+        "WorkerId": NotRequired[str],
     },
-    total=False,
 )
 
 NotifyWorkersRequestRequestTypeDef = TypedDict(
@@ -918,101 +694,82 @@ NotifyWorkersResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 ParameterMapEntryTypeDef = TypedDict(
     "ParameterMapEntryTypeDef",
     {
-        "Key": str,
-        "Values": Sequence[str],
+        "Key": NotRequired[str],
+        "Values": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 PolicyParameterTypeDef = TypedDict(
     "PolicyParameterTypeDef",
     {
-        "Key": str,
-        "Values": Sequence[str],
-        "MapEntries": Sequence["ParameterMapEntryTypeDef"],
+        "Key": NotRequired[str],
+        "Values": NotRequired[Sequence[str]],
+        "MapEntries": NotRequired[Sequence["ParameterMapEntryTypeDef"]],
     },
-    total=False,
 )
 
 QualificationRequestTypeDef = TypedDict(
     "QualificationRequestTypeDef",
     {
-        "QualificationRequestId": str,
-        "QualificationTypeId": str,
-        "WorkerId": str,
-        "Test": str,
-        "Answer": str,
-        "SubmitTime": datetime,
+        "QualificationRequestId": NotRequired[str],
+        "QualificationTypeId": NotRequired[str],
+        "WorkerId": NotRequired[str],
+        "Test": NotRequired[str],
+        "Answer": NotRequired[str],
+        "SubmitTime": NotRequired[datetime],
     },
-    total=False,
 )
 
-_RequiredQualificationRequirementTypeDef = TypedDict(
-    "_RequiredQualificationRequirementTypeDef",
+QualificationRequirementTypeDef = TypedDict(
+    "QualificationRequirementTypeDef",
     {
         "QualificationTypeId": str,
         "Comparator": ComparatorType,
+        "IntegerValues": NotRequired[Sequence[int]],
+        "LocaleValues": NotRequired[Sequence["LocaleTypeDef"]],
+        "RequiredToPreview": NotRequired[bool],
+        "ActionsGuarded": NotRequired[HITAccessActionsType],
     },
 )
-_OptionalQualificationRequirementTypeDef = TypedDict(
-    "_OptionalQualificationRequirementTypeDef",
-    {
-        "IntegerValues": Sequence[int],
-        "LocaleValues": Sequence["LocaleTypeDef"],
-        "RequiredToPreview": bool,
-        "ActionsGuarded": HITAccessActionsType,
-    },
-    total=False,
-)
-
-
-class QualificationRequirementTypeDef(
-    _RequiredQualificationRequirementTypeDef, _OptionalQualificationRequirementTypeDef
-):
-    pass
-
 
 QualificationTypeDef = TypedDict(
     "QualificationTypeDef",
     {
-        "QualificationTypeId": str,
-        "WorkerId": str,
-        "GrantTime": datetime,
-        "IntegerValue": int,
-        "LocaleValue": "LocaleTypeDef",
-        "Status": QualificationStatusType,
+        "QualificationTypeId": NotRequired[str],
+        "WorkerId": NotRequired[str],
+        "GrantTime": NotRequired[datetime],
+        "IntegerValue": NotRequired[int],
+        "LocaleValue": NotRequired["LocaleTypeDef"],
+        "Status": NotRequired[QualificationStatusType],
     },
-    total=False,
 )
 
 QualificationTypeTypeDef = TypedDict(
     "QualificationTypeTypeDef",
     {
-        "QualificationTypeId": str,
-        "CreationTime": datetime,
-        "Name": str,
-        "Description": str,
-        "Keywords": str,
-        "QualificationTypeStatus": QualificationTypeStatusType,
-        "Test": str,
-        "TestDurationInSeconds": int,
-        "AnswerKey": str,
-        "RetryDelayInSeconds": int,
-        "IsRequestable": bool,
-        "AutoGranted": bool,
-        "AutoGrantedValue": int,
+        "QualificationTypeId": NotRequired[str],
+        "CreationTime": NotRequired[datetime],
+        "Name": NotRequired[str],
+        "Description": NotRequired[str],
+        "Keywords": NotRequired[str],
+        "QualificationTypeStatus": NotRequired[QualificationTypeStatusType],
+        "Test": NotRequired[str],
+        "TestDurationInSeconds": NotRequired[int],
+        "AnswerKey": NotRequired[str],
+        "RetryDelayInSeconds": NotRequired[int],
+        "IsRequestable": NotRequired[bool],
+        "AutoGranted": NotRequired[bool],
+        "AutoGrantedValue": NotRequired[int],
     },
-    total=False,
 )
 
 RejectAssignmentRequestRequestTypeDef = TypedDict(
@@ -1023,27 +780,13 @@ RejectAssignmentRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredRejectQualificationRequestRequestRequestTypeDef = TypedDict(
-    "_RequiredRejectQualificationRequestRequestRequestTypeDef",
+RejectQualificationRequestRequestRequestTypeDef = TypedDict(
+    "RejectQualificationRequestRequestRequestTypeDef",
     {
         "QualificationRequestId": str,
+        "Reason": NotRequired[str],
     },
 )
-_OptionalRejectQualificationRequestRequestRequestTypeDef = TypedDict(
-    "_OptionalRejectQualificationRequestRequestRequestTypeDef",
-    {
-        "Reason": str,
-    },
-    total=False,
-)
-
-
-class RejectQualificationRequestRequestRequestTypeDef(
-    _RequiredRejectQualificationRequestRequestRequestTypeDef,
-    _OptionalRejectQualificationRequestRequestRequestTypeDef,
-):
-    pass
-
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -1051,7 +794,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -1059,82 +802,55 @@ ResponseMetadataTypeDef = TypedDict(
 ReviewActionDetailTypeDef = TypedDict(
     "ReviewActionDetailTypeDef",
     {
-        "ActionId": str,
-        "ActionName": str,
-        "TargetId": str,
-        "TargetType": str,
-        "Status": ReviewActionStatusType,
-        "CompleteTime": datetime,
-        "Result": str,
-        "ErrorCode": str,
+        "ActionId": NotRequired[str],
+        "ActionName": NotRequired[str],
+        "TargetId": NotRequired[str],
+        "TargetType": NotRequired[str],
+        "Status": NotRequired[ReviewActionStatusType],
+        "CompleteTime": NotRequired[datetime],
+        "Result": NotRequired[str],
+        "ErrorCode": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredReviewPolicyTypeDef = TypedDict(
-    "_RequiredReviewPolicyTypeDef",
+ReviewPolicyTypeDef = TypedDict(
+    "ReviewPolicyTypeDef",
     {
         "PolicyName": str,
+        "Parameters": NotRequired[Sequence["PolicyParameterTypeDef"]],
     },
 )
-_OptionalReviewPolicyTypeDef = TypedDict(
-    "_OptionalReviewPolicyTypeDef",
-    {
-        "Parameters": Sequence["PolicyParameterTypeDef"],
-    },
-    total=False,
-)
-
-
-class ReviewPolicyTypeDef(_RequiredReviewPolicyTypeDef, _OptionalReviewPolicyTypeDef):
-    pass
-
 
 ReviewReportTypeDef = TypedDict(
     "ReviewReportTypeDef",
     {
-        "ReviewResults": List["ReviewResultDetailTypeDef"],
-        "ReviewActions": List["ReviewActionDetailTypeDef"],
+        "ReviewResults": NotRequired[List["ReviewResultDetailTypeDef"]],
+        "ReviewActions": NotRequired[List["ReviewActionDetailTypeDef"]],
     },
-    total=False,
 )
 
 ReviewResultDetailTypeDef = TypedDict(
     "ReviewResultDetailTypeDef",
     {
-        "ActionId": str,
-        "SubjectId": str,
-        "SubjectType": str,
-        "QuestionId": str,
-        "Key": str,
-        "Value": str,
+        "ActionId": NotRequired[str],
+        "SubjectId": NotRequired[str],
+        "SubjectType": NotRequired[str],
+        "QuestionId": NotRequired[str],
+        "Key": NotRequired[str],
+        "Value": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredSendBonusRequestRequestTypeDef = TypedDict(
-    "_RequiredSendBonusRequestRequestTypeDef",
+SendBonusRequestRequestTypeDef = TypedDict(
+    "SendBonusRequestRequestTypeDef",
     {
         "WorkerId": str,
         "BonusAmount": str,
         "AssignmentId": str,
         "Reason": str,
+        "UniqueRequestToken": NotRequired[str],
     },
 )
-_OptionalSendBonusRequestRequestTypeDef = TypedDict(
-    "_OptionalSendBonusRequestRequestTypeDef",
-    {
-        "UniqueRequestToken": str,
-    },
-    total=False,
-)
-
-
-class SendBonusRequestRequestTypeDef(
-    _RequiredSendBonusRequestRequestTypeDef, _OptionalSendBonusRequestRequestTypeDef
-):
-    pass
-
 
 SendTestEventNotificationRequestRequestTypeDef = TypedDict(
     "SendTestEventNotificationRequestRequestTypeDef",
@@ -1152,27 +868,13 @@ UpdateExpirationForHITRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateHITReviewStatusRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateHITReviewStatusRequestRequestTypeDef",
+UpdateHITReviewStatusRequestRequestTypeDef = TypedDict(
+    "UpdateHITReviewStatusRequestRequestTypeDef",
     {
         "HITId": str,
+        "Revert": NotRequired[bool],
     },
 )
-_OptionalUpdateHITReviewStatusRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateHITReviewStatusRequestRequestTypeDef",
-    {
-        "Revert": bool,
-    },
-    total=False,
-)
-
-
-class UpdateHITReviewStatusRequestRequestTypeDef(
-    _RequiredUpdateHITReviewStatusRequestRequestTypeDef,
-    _OptionalUpdateHITReviewStatusRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateHITTypeOfHITRequestRequestTypeDef = TypedDict(
     "UpdateHITTypeOfHITRequestRequestTypeDef",
@@ -1182,57 +884,29 @@ UpdateHITTypeOfHITRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateNotificationSettingsRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateNotificationSettingsRequestRequestTypeDef",
+UpdateNotificationSettingsRequestRequestTypeDef = TypedDict(
+    "UpdateNotificationSettingsRequestRequestTypeDef",
     {
         "HITTypeId": str,
+        "Notification": NotRequired["NotificationSpecificationTypeDef"],
+        "Active": NotRequired[bool],
     },
 )
-_OptionalUpdateNotificationSettingsRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateNotificationSettingsRequestRequestTypeDef",
-    {
-        "Notification": "NotificationSpecificationTypeDef",
-        "Active": bool,
-    },
-    total=False,
-)
 
-
-class UpdateNotificationSettingsRequestRequestTypeDef(
-    _RequiredUpdateNotificationSettingsRequestRequestTypeDef,
-    _OptionalUpdateNotificationSettingsRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredUpdateQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateQualificationTypeRequestRequestTypeDef",
+UpdateQualificationTypeRequestRequestTypeDef = TypedDict(
+    "UpdateQualificationTypeRequestRequestTypeDef",
     {
         "QualificationTypeId": str,
+        "Description": NotRequired[str],
+        "QualificationTypeStatus": NotRequired[QualificationTypeStatusType],
+        "Test": NotRequired[str],
+        "AnswerKey": NotRequired[str],
+        "TestDurationInSeconds": NotRequired[int],
+        "RetryDelayInSeconds": NotRequired[int],
+        "AutoGranted": NotRequired[bool],
+        "AutoGrantedValue": NotRequired[int],
     },
 )
-_OptionalUpdateQualificationTypeRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateQualificationTypeRequestRequestTypeDef",
-    {
-        "Description": str,
-        "QualificationTypeStatus": QualificationTypeStatusType,
-        "Test": str,
-        "AnswerKey": str,
-        "TestDurationInSeconds": int,
-        "RetryDelayInSeconds": int,
-        "AutoGranted": bool,
-        "AutoGrantedValue": int,
-    },
-    total=False,
-)
-
-
-class UpdateQualificationTypeRequestRequestTypeDef(
-    _RequiredUpdateQualificationTypeRequestRequestTypeDef,
-    _OptionalUpdateQualificationTypeRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateQualificationTypeResponseTypeDef = TypedDict(
     "UpdateQualificationTypeResponseTypeDef",
@@ -1245,8 +919,7 @@ UpdateQualificationTypeResponseTypeDef = TypedDict(
 WorkerBlockTypeDef = TypedDict(
     "WorkerBlockTypeDef",
     {
-        "WorkerId": str,
-        "Reason": str,
+        "WorkerId": NotRequired[str],
+        "Reason": NotRequired[str],
     },
-    total=False,
 )
